MODELS = {

  "Qwen3-Coder-Next-GGUF": {
    "model_max_length": 32768,
    "include": "Qwen3-Coder-Next-Q4_K_M/*.gguf",
    "name": "Qwen3-Coder-Next-GGUF",
    "framework": "llama_cpp",
    "hub_id": "Qwen/Qwen3-Coder-Next-GGUF",
    "filename": "Qwen3-Coder-Next-Q4_K_M-00001-of-00004.gguf",
    "folder": "gguf/text-generation/Qwen/Qwen3-Coder-Next-GGUF",
    "tasks": ["text-generation"],
    "primary_task": "text-generation",
    "port": 7002
  },
  "DAN-L3-R1-8B-i1-GGUF": {
    "filename": "DAN-L3-R1-8B.i1-IQ1_M.gguf",
    "folder": "mradermacher/DAN-L3-R1-8B-i1-GGUF",
    "framework": "llama_cpp",
    "host": None,
    "hub_id": "gguf/text-generation/mradermacher/DAN-L3-R1-8B-i1-GGUF",
    "include": None,
    "model_max_length": 32768,
    "name": "DAN-L3-R1-8B-i1-GGUF",
    "port": 7004,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "DAN-Qwen3-1.7B": {
    "filename": None,
    "folder": "transformers/text-generation/UnfilteredAI/DAN-Qwen3-1.7B",
    "framework": "transformers",
    "host": None,
    "hub_id": "/UnfilteredAI/DAN-Qwen3-1.7B",
    "include": None,
    "model_max_length": 40960,
    "name": "DAN-Qwen3-1.7B",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation",
      "text-generation"
    ]
  },
  "DeepCoder-14B-Preview": {
    "filename": None,
    "folder": "transformers/text-generation/agentica-org/DeepCoder-14B-Preview",
    "framework": "transformers",
    "host": None,
    "hub_id": "agentica-org/DeepCoder-14B-Preview",
    "include": None,
    "model_max_length": 16384,
    "name": "DeepCoder-14B-Preview",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "MiniCPM-V-4.6": {
    "filename": None,
    "folder": "transformers/image-text-to-text/openbmb/MiniCPM-V-4.6",
    "framework": "transformers",
    "host": None,
    "hub_id": "openbmb/MiniCPM-V-4.6",
    "include": None,
    "model_key": "MiniCPM-V-4.6",
    "model_max_length": 262144,
    "name": "MiniCPM-V-4.6",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation",
      "image-text-to-text"
    ],
    "timeout_s": 3600
  },
  "Qwen2.5-Coder-1.5B-Instruct-GGUF": {
    "filename": "Qwen2.5-Coder-1.5B-Instruct-Q4_K_M.gguf",
    "folder": "gguf/text-generation/bartowski/Qwen2.5-Coder-1.5B-Instruct-GGUF",
    "framework": "llama_cpp",
    "host": None,
    "hub_id": "bartowski/Qwen2.5-Coder-1.5B-Instruct-GGUF",
    "include": None,
    "model_max_length": 32768,
    "name": "Qwen2.5-Coder-1.5B-Instruct-GGUF",
    "port": 7000,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "Qwen2.5-Coder-3B-Instruct-GGUF": {
    "filename": "qwen2.5-coder-3b-instruct-q4_k_m.gguf",
    "folder": "gguf/text-generation/Qwen/Qwen2.5-Coder-3B-Instruct-GGUF",
    "framework": "llama_cpp",
    "host": None,
    "hub_id": "Qwen/Qwen2.5-Coder-3B-Instruct-GGUF",
    "include": None,
    "model_max_length": 32768,
    "name": "Qwen2.5-Coder-3B-Instruct-GGUF",
    "port": 7001,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "Qwen2.5-VL-3B-Instruct": {
    "filename": None,
    "folder": "transformers/image-text-to-text/Qwen/Qwen2.5-VL-3B-Instruct",
    "framework": "transformers",
    "host": None,
    "hub_id": "Qwen/Qwen2.5-VL-3B-Instruct",
    "include": None,
    "model_max_length": 131072,
    "name": "Qwen2.5-VL-3B-Instruct",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "Qwen2.5-VL-7B-Instruct": {
    "filename": None,
    "folder": "transformers/image-text-to-text/Qwen/Qwen2.5-VL-7B-Instruct",
    "framework": "transformers",
    "host": None,
    "hub_id": "Qwen/Qwen2.5-VL-7B-Instruct",
    "include": None,
    "model_max_length": 131072,
    "name": "Qwen2.5-VL-7B-Instruct",
    "port": 7005,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "Qwen3.6-27B-AEON-Ultimate-Uncensored-GPTQ-Pro-FOEM-4bit-g128": {
    "filename": None,
    "folder": "transformers/text-generation/groxaxo/Qwen3.6-27B-AEON-Ultimate-Uncensored-GPTQ-Pro-FOEM-4bit-g128",
    "framework": "transformers",
    "host": None,
    "hub_id": "groxaxo/Qwen3.6-27B-AEON-Ultimate-Uncensored-GPTQ-Pro-FOEM-4bit-g128",
    "include": None,
    "model_max_length": 262144,
    "name": "Qwen3.6-27B-AEON-Ultimate-Uncensored-GPTQ-Pro-FOEM-4bit-g128",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },

  "flux2-klein-9b-uncensored-text-encoder": {
    "filename": "flux2-klein-9b-uncensored-f16.gguf",
    "folder": "transformers/text-generation/ponpoke/flux2-klein-9b-uncensored-text-encoder",
    "framework": "llama_cpp",
    "host": None,
    "hub_id": "ponpoke/flux2-klein-9b-uncensored-text-encoder",
    "include": None,
    "model_max_length": 131072,
    "name": "flux2-klein-9b-uncensored-text-encoder",
    "port": 7003,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "gte-large-en-v1.5": {
    "filename": None,
    "folder": "transformers/feature-extraction/Alibaba-NLP/gte-large-en-v1.5",
    "framework": "transformers",
    "host": None,
    "hub_id": "Alibaba-NLP/gte-large-en-v1.5",
    "include": None,
    "model_max_length": 32768,
    "name": "gte-large-en-v1.5",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "led-large-16384": {
    "filename": None,
    "folder": "transformers/summarization/allenai/led-large-16384",
    "framework": "transformers",
    "host": None,
    "hub_id": "allenai/led-large-16384",
    "include": None,
    "model_max_length": 16384,
    "name": "led-large-16384",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
    "all-minilm-l6-v2": {
    "filename": None,
    "folder": "transformers/feature-extraction/sentence-transformers/all-minilm-l6-v2",
    "framework": "transformers",
    "host": None,
    "hub_id": "sentence-transformers/all-minilm-l6-v2",
    "include": None,
    "model_max_length": 512,
    "name": "all-minilm-l6-v2",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "flan-t5-xl": {
    "filename": None,
    "folder": "transformers/summarization/google/flan-t5-xl",
    "framework": "transformers",
    "host": None,
    "hub_id": "google/flan-t5-xl",
    "include": None,
    "model_max_length": 512,
    "name": "flan-t5-xl",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  },
  "qwen": {
    "filename": None,
    "framework": "transformers",
    "hub_id": "qwen",
    "include": None,
    "name": "qwen",
    "task": "text-generation"
  },
  "text_summarization": {
    "filename": None,
    "folder": "transformers/summarization/Falconsai/text_summarization",
    "framework": "transformers",
    "host": None,
    "hub_id": "Falconsai/text_summarization",
    "include": None,
    "model_key": "text_summarization",
    "model_max_length": 512,
    "name": "text_summarization",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ],
    "timeout_s": 3600
  },
  "whisper-large-v3": {
    "filename": None,
    "folder": "transformers/automatic-speech-recognition/openai/whisper-large-v3",
    "framework": "transformers",
    "host": None,
    "hub_id": "openai/whisper-large-v3",
    "include": None,
    "model_max_length": 1000000000000000019884624838656,
    "name": "whisper-large-v3",
    "port": None,
    "primary_task": "text-generation",
    "tasks": [
      "text-generation"
    ]
  }
}
